@@ -17,7 +17,6 @@
 package org.apache.activemq.artemis.core.protocol.openwire;
 
 import javax.jms.IllegalStateException;
-import javax.jms.InvalidClientIDException;
 import javax.jms.InvalidDestinationException;
 import javax.jms.JMSSecurityException;
 import javax.transaction.xa.XAException;
@@ -148,8 +147,6 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
    private final OpenWireProtocolManager protocolManager;
 
-   private boolean destroyed = false;
-
    private volatile ScheduledFuture ttlCheck;
 
    //separated in/out wireFormats allow deliveries (eg async and consumers) to not slow down bufferReceived
@@ -684,18 +681,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    private void rollbackInProgressLocalTransactions() {
 
       for (Transaction tx : txMap.values()) {
-         AMQSession session = (AMQSession) tx.getProtocolData();
-         if (session != null) {
-            session.getCoreSession().resetTX(tx);
-            try {
-               session.getCoreSession().rollback(false);
-            } catch (Exception expectedOnExistingOutcome) {
-            } finally {
-               session.getCoreSession().resetTX(null);
-            }
-         } else {
-            tx.tryRollback();
-         }
+         tx.tryRollback();
       }
    }
 
@@ -731,7 +717,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
          for (SessionId sessionId : sessionIdMap.values()) {
             AMQSession session = sessions.get(sessionId);
             if (session != null) {
-               session.close();
+               session.close(fail);
             }
          }
          internalSession.close(false);
@@ -774,7 +760,11 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
       final ThresholdActor<Command> localVisibleActor = openWireActor;
       if (localVisibleActor != null) {
-         localVisibleActor.shutdown(() -> doFail(me, message));
+         localVisibleActor.requestShutdown();
+      }
+
+      if (executor != null) {
+         executor.execute(() -> doFail(me, message));
       } else {
          doFail(me, message);
       }
@@ -784,8 +774,6 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
       recoverOperationContext();
 
-      rollbackInProgressLocalTransactions();
-
       if (me != null) {
          //filter it like the other protocols
          if (!(me instanceof ActiveMQRemoteDisconnectException)) {
@@ -794,10 +782,29 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       }
       try {
          if (this.getConnectionInfo() != null) {
-            protocolManager.removeConnection(this.getConnectionInfo(), me);
+            protocolManager.removeConnection(getClientID(), this);
          }
-      } catch (InvalidClientIDException e) {
-         logger.warn("Couldn't close connection because invalid clientID", e);
+      } finally {
+         try {
+            disconnect(false);
+         } catch (Throwable e) {
+            // it should never happen, but never say never
+            logger.debug("OpenWireConnection::disconnect failure", e);
+         }
+
+         // there may be some transactions not associated with sessions
+         // deal with them after sessions are removed via connection removal
+         operationContext.executeOnCompletion(new IOCallback() {
+            @Override
+            public void done() {
+               rollbackInProgressLocalTransactions();
+            }
+
+            @Override
+            public void onError(int errorCode, String errorMessage) {
+               rollbackInProgressLocalTransactions();
+            }
+         });
       }
       shutdown(true);
    }
@@ -877,29 +884,6 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       internalSession = server.createSession(UUIDGenerator.getInstance().generateStringUUID(), context.getUserName(), info.getPassword(), -1, this, true, false, false, false, null, null, true, operationContext, protocolManager.getPrefixes(), protocolManager.getSecurityDomain(), validatedUser, false);
    }
 
-   //raise the refCount of context
-   public void reconnect(AMQConnectionContext existingContext, ConnectionInfo info) throws Exception {
-      this.context = existingContext;
-      WireFormatInfo wireFormatInfo = inWireFormat.getPreferedWireFormatInfo();
-      // Older clients should have been defaulting this field to true.. but
-      // they were not.
-      if (wireFormatInfo != null && wireFormatInfo.getVersion() <= 2) {
-         info.setClientMaster(true);
-      }
-      if (info.getClientIp() == null) {
-         info.setClientIp(getRemoteAddress());
-      }
-      createInternalSession(info);
-      state = new ConnectionState(info);
-      state.reset(info);
-
-      context.setConnection(this);
-      context.setConnectionState(state);
-      context.setClientMaster(info.isClientMaster());
-      context.setFaultTolerant(info.isFaultTolerant());
-      context.setReconnect(true);
-   }
-
    /**
     * This will answer with commands to the client
     */
@@ -998,7 +982,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
             return;
          }
 
-         amqSession.start();
+         consumersList.forEach((c) -> c.start());
 
          if (AdvisorySupport.isAdvisoryTopic(info.getDestination())) {
             //advisory for temp destinations
@@ -1138,6 +1122,7 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    public AMQSession addSession(SessionInfo ss) {
       AMQSession amqSession = new AMQSession(getState().getInfo(), ss, server, this, protocolManager, coreMessageObjectPools);
       amqSession.initialize();
+      amqSession.start();
 
       sessions.put(ss.getSessionId(), amqSession);
       sessionIdMap.put(amqSession.getCoreSession().getName(), ss.getSessionId());
@@ -1233,6 +1218,8 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
             }
             dispatchAsync(command);
          }
+         // During a chanceClientID a disconnect could have been sent by the client, and the client will then re-issue a connect packet
+         destroyed = false;
          return null;
 
       }
@@ -1338,7 +1325,11 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
 
       @Override
       public Response processRollbackTransaction(TransactionInfo info) throws Exception {
-         Transaction tx = lookupTX(info.getTransactionId(), null, true);
+         Transaction tx = lookupTX(info.getTransactionId(), null);
+
+         if (tx == null) {
+            throw new IllegalStateException("Transaction not started, " + info.getTransactionId());
+         }
 
          final AMQSession amqSession;
          if (tx != null) {
@@ -1354,11 +1345,12 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
             if (amqSession != null) {
                amqSession.getCoreSession().resetTX(tx);
 
-               try {
-                  returnReferences(tx, amqSession);
-               } finally {
-                  amqSession.getCoreSession().resetTX(null);
-               }
+               tx.addOperation(new TransactionOperationAbstract() {
+                  @Override
+                  public void beforeRollback(Transaction tx) throws Exception {
+                     returnReferences(tx, amqSession);
+                  }
+               });
             }
          }
 
@@ -1406,6 +1398,9 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
             }
          } else {
             if (tx != null) {
+               // returnReferences() is only interested in acked messages already in the tx, hence we bypass
+               // getCoreSession().rollback() logic for CORE which would add any prefetched/delivered which have
+               // not yet been processed by the openwire client.
                tx.rollback();
             }
          }
@@ -1490,18 +1485,46 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       @Override
       public Response processBeginTransaction(TransactionInfo info) throws Exception {
          final TransactionId txID = info.getTransactionId();
-
          try {
             internalSession.resetTX(null);
             if (txID.isXATransaction()) {
-               Xid xid = OpenWireUtil.toXID(txID);
+               final Xid xid = OpenWireUtil.toXID(txID);
                internalSession.xaStart(xid);
+               final ResourceManager resourceManager = server.getResourceManager();
+               final Transaction transaction = resourceManager.getTransaction(xid);
+               transaction.addOperation(new TransactionOperationAbstract() {
+                  @Override
+                  public void afterCommit(Transaction tx) {
+                     removeFromResourceManager();
+                  }
+
+                  @Override
+                  public void afterRollback(Transaction tx) {
+                     removeFromResourceManager();
+                  }
+
+                  private void removeFromResourceManager() {
+                     try {
+                        resourceManager.removeTransaction(xid, getRemotingConnection());
+                     } catch (ActiveMQException bestEffort) {
+                     }
+                  }
+               });
             } else {
-               Transaction transaction = internalSession.newTransaction();
+               final Transaction transaction = internalSession.newTransaction();
                txMap.put(txID, transaction);
                transaction.addOperation(new TransactionOperationAbstract() {
                   @Override
                   public void afterCommit(Transaction tx) {
+                     removeFromTxMap();
+                  }
+
+                  @Override
+                  public void afterRollback(Transaction tx) {
+                     removeFromTxMap();
+                  }
+
+                  private void removeFromTxMap() {
                      txMap.remove(txID);
                   }
                });
@@ -1520,7 +1543,11 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       private Response processCommit(TransactionInfo info, boolean onePhase) throws Exception {
          TransactionId txID = info.getTransactionId();
 
-         Transaction tx = lookupTX(txID, null, true);
+         Transaction tx = lookupTX(txID, null);
+
+         if (tx == null) {
+            throw new IllegalStateException("Transaction not started, " + txID);
+         }
 
          if (txID.isXATransaction()) {
             ResourceManager resourceManager = server.getResourceManager();
@@ -1557,7 +1584,13 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
             }
          } else {
             if (tx != null) {
-               tx.commit(onePhase);
+               AMQSession amqSession = (AMQSession) tx.getProtocolData();
+               if (amqSession != null) {
+                  amqSession.getCoreSession().resetTX(tx);
+                  amqSession.getCoreSession().commit();
+               } else {
+                  tx.commit(true);
+               }
             }
          }
 
@@ -1630,8 +1663,6 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
                logger.warn("Error during method invocation", e);
                throw e;
             }
-         } else {
-            txMap.remove(txID);
          }
 
          return null;
@@ -1705,8 +1736,6 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
                sendException(e);
             }
             throw e;
-         } finally {
-            session.getCoreSession().resetTX(null);
          }
 
          return null;
@@ -1716,6 +1745,11 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       public Response processMessageAck(MessageAck ack) throws Exception {
          AMQSession session = getSession(ack.getConsumerId().getParentId());
          Transaction tx = lookupTX(ack.getTransactionId(), session);
+
+         if (ack.getTransactionId() != null && tx == null) {
+            throw new IllegalStateException("Transaction not started, " + ack.getTransactionId());
+         }
+
          session.getCoreSession().resetTX(tx);
 
          try {
@@ -1725,8 +1759,6 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
             if (tx != null) {
                tx.markAsRollbackOnly(new ActiveMQException(e.getMessage()));
             }
-         } finally {
-            session.getCoreSession().resetTX(null);
          }
          return null;
       }
@@ -1771,13 +1803,13 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
       @Override
       public Response processRemoveConnection(ConnectionId id, long lastDeliveredSequenceId) throws Exception {
          //we let protocol manager to handle connection add/remove
+         for (SessionState sessionState : state.getSessionStates()) {
+            propagateLastSequenceId(sessionState, lastDeliveredSequenceId);
+         }
          try {
-            for (SessionState sessionState : state.getSessionStates()) {
-               propagateLastSequenceId(sessionState, lastDeliveredSequenceId);
-            }
-            protocolManager.removeConnection(state.getInfo(), null);
-         } catch (Throwable e) {
-            // log
+            protocolManager.removeConnection(getClientID(), OpenWireConnection.this);
+         } finally {
+            OpenWireConnection.this.disconnect(false);
          }
          return null;
       }
@@ -1819,21 +1851,16 @@ public class OpenWireConnection extends AbstractRemotingConnection implements Se
    }
 
    private Transaction lookupTX(TransactionId txID, AMQSession session) throws Exception {
-      return lookupTX(txID, session, false);
-   }
-
-   private Transaction lookupTX(TransactionId txID, AMQSession session, boolean remove) throws Exception {
       if (txID == null) {
          return null;
       }
 
-      Xid xid = null;
       Transaction transaction;
       if (txID.isXATransaction()) {
-         xid = OpenWireUtil.toXID(txID);
-         transaction = remove ? server.getResourceManager().removeTransaction(xid, this) : server.getResourceManager().getTransaction(xid);
+         final Xid xid = OpenWireUtil.toXID(txID);
+         transaction = server.getResourceManager().getTransaction(xid);
       } else {
-         transaction = remove ? txMap.remove(txID) : txMap.get(txID);
+         transaction = txMap.get(txID);
       }
 
       if (transaction == null) {
