@@ -32,12 +32,12 @@ import org.apache.activemq.artemis.core.config.FileDeploymentManager;
 import org.apache.activemq.artemis.core.config.HAPolicyConfiguration;
 import org.apache.activemq.artemis.core.config.ScaleDownConfiguration;
 import org.apache.activemq.artemis.core.config.WildcardConfiguration;
-import org.apache.activemq.artemis.core.config.ha.LiveOnlyPolicyConfiguration;
-import org.apache.activemq.artemis.core.config.ha.SharedStoreMasterPolicyConfiguration;
+import org.apache.activemq.artemis.core.config.ha.PrimaryOnlyPolicyConfiguration;
+import org.apache.activemq.artemis.core.config.ha.SharedStorePrimaryPolicyConfiguration;
 import org.apache.activemq.artemis.core.deployers.impl.FileConfigurationParser;
 import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
-import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
+import org.apache.activemq.artemis.tests.util.ServerTestBase;
 import org.apache.activemq.artemis.utils.ClassloadingUtil;
 import org.apache.activemq.artemis.utils.DefaultSensitiveStringCodec;
 import org.apache.activemq.artemis.utils.PasswordMaskingUtil;
@@ -45,7 +45,7 @@ import org.apache.activemq.artemis.utils.StringPrintStream;
 import org.junit.Assert;
 import org.junit.Test;
 
-public class FileConfigurationParserTest extends ActiveMQTestBase {
+public class FileConfigurationParserTest extends ServerTestBase {
 
    /**
     * These "InvalidConfigurationTest*.xml" files are modified copies of {@value
@@ -166,17 +166,17 @@ public class FileConfigurationParserTest extends ActiveMQTestBase {
    public void testParsingHaSharedStoreWaitForActivation() throws Exception {
       FileConfigurationParser parser = new FileConfigurationParser();
 
-      String configStr = firstPart + "<ha-policy><shared-store><master><wait-for-activation>false</wait-for-activation></master></shared-store></ha-policy>" + lastPart;
+      String configStr = firstPart + "<ha-policy><shared-store><primary><wait-for-activation>false</wait-for-activation></primary></shared-store></ha-policy>" + lastPart;
       ByteArrayInputStream input = new ByteArrayInputStream(configStr.getBytes(StandardCharsets.UTF_8));
 
       Configuration config = parser.parseMainConfig(input);
       HAPolicyConfiguration haConfig = config.getHAPolicyConfiguration();
 
-      assertTrue(haConfig instanceof SharedStoreMasterPolicyConfiguration);
+      assertTrue(haConfig instanceof SharedStorePrimaryPolicyConfiguration);
 
-      SharedStoreMasterPolicyConfiguration masterConfig = (SharedStoreMasterPolicyConfiguration) haConfig;
+      SharedStorePrimaryPolicyConfiguration primaryConfig = (SharedStorePrimaryPolicyConfiguration) haConfig;
 
-      assertFalse(masterConfig.isWaitForActivation());
+      assertFalse(primaryConfig.isWaitForActivation());
    }
 
    @Test
@@ -311,6 +311,13 @@ public class FileConfigurationParserTest extends ActiveMQTestBase {
          "         <connector-ref>remote-connector</connector-ref>\n" +
          "      </static-connectors>\n" +
          "   </bridge>\n" +
+         "   <bridge name=\"my-other-bridge\">\n" +
+         "      <static-connectors>\n" +
+         "         <connector-ref>remote-connector</connector-ref>\n" +
+         "      </static-connectors>\n" +
+         "      <forwarding-address>mincing-machine</forwarding-address>\n" +
+         "      <queue-name>sausage-factory</queue-name>\n" +
+         "   </bridge>\n" +
          "</bridges>\n"
          + lastPart;
       ByteArrayInputStream input = new ByteArrayInputStream(configStr.getBytes(StandardCharsets.UTF_8));
@@ -318,7 +325,7 @@ public class FileConfigurationParserTest extends ActiveMQTestBase {
       Configuration config = parser.parseMainConfig(input);
 
       List<BridgeConfiguration> bridgeConfigs = config.getBridgeConfigurations();
-      assertEquals(1, bridgeConfigs.size());
+      assertEquals(2, bridgeConfigs.size());
 
       BridgeConfiguration bconfig = bridgeConfigs.get(0);
 
@@ -358,10 +365,10 @@ public class FileConfigurationParserTest extends ActiveMQTestBase {
       Configuration config = parser.parseMainConfig(input);
 
       HAPolicyConfiguration haConfig = config.getHAPolicyConfiguration();
-      assertTrue(haConfig instanceof LiveOnlyPolicyConfiguration);
+      assertTrue(haConfig instanceof PrimaryOnlyPolicyConfiguration);
 
-      LiveOnlyPolicyConfiguration liveOnlyCfg = (LiveOnlyPolicyConfiguration) haConfig;
-      ScaleDownConfiguration scaledownCfg = liveOnlyCfg.getScaleDownConfiguration();
+      PrimaryOnlyPolicyConfiguration primaryOnlyCfg = (PrimaryOnlyPolicyConfiguration) haConfig;
+      ScaleDownConfiguration scaledownCfg = primaryOnlyCfg.getScaleDownConfiguration();
       List<String> connectors = scaledownCfg.getConnectors();
       assertEquals(1, connectors.size());
       String connector = connectors.get(0);
@@ -414,7 +421,7 @@ public class FileConfigurationParserTest extends ActiveMQTestBase {
 
    @Test
    public void testParsePageLimitSettings() throws Exception {
-      String configStr = "<configuration><address-settings>" + "\n" + "<address-setting match=\"foo\">" + "\n" + "<max-read-page-bytes>1k</max-read-page-bytes><page-limit-bytes>10G</page-limit-bytes><page-limit-messages>3221225472</page-limit-messages><page-full-policy>FAIL</page-full-policy><max-read-page-messages>33</max-read-page-messages>.\n" + "</address-setting>" + "\n" + "</address-settings></configuration>" + "\n";
+      String configStr = "<configuration><address-settings>" + "\n" + "<address-setting match=\"foo\">" + "\n" + "<max-read-page-bytes>1k</max-read-page-bytes><prefetch-page-bytes>100M</prefetch-page-bytes><prefetch-page-messages>777</prefetch-page-messages><page-limit-bytes>10G</page-limit-bytes><page-limit-messages>3221225472</page-limit-messages><page-full-policy>FAIL</page-full-policy><max-read-page-messages>33</max-read-page-messages>.\n" + "</address-setting>" + "\n" + "</address-settings></configuration>" + "\n";
 
       FileConfigurationParser parser = new FileConfigurationParser();
       ByteArrayInputStream input = new ByteArrayInputStream(configStr.getBytes(StandardCharsets.UTF_8));
@@ -424,6 +431,8 @@ public class FileConfigurationParserTest extends ActiveMQTestBase {
       Assert.assertEquals(1024, settings.getMaxReadPageBytes());
       Assert.assertEquals(33, settings.getMaxReadPageMessages());
       Assert.assertEquals(10L * 1024 * 1024 * 1024, settings.getPageLimitBytes().longValue());
+      Assert.assertEquals(100 * 1024 * 1024, settings.getPrefetchPageBytes());
+      Assert.assertEquals(777, settings.getPrefetchPageMessages());
       Assert.assertEquals(3L * 1024 * 1024 * 1024, settings.getPageLimitMessages().longValue());
       Assert.assertEquals("FAIL", settings.getPageFullMessagePolicy().toString());
    }
@@ -441,6 +450,53 @@ public class FileConfigurationParserTest extends ActiveMQTestBase {
       Assert.assertEquals(-1, settings.getMaxReadPageMessages());
    }
 
+   @Test
+   public void testLiteralMatchMarkers() throws Exception {
+      String configStr = "<configuration><literal-match-markers>()</literal-match-markers><address-settings>\n<address-setting match=\"(foo)\">\n<max-read-page-bytes>-1</max-read-page-bytes></address-setting>\n</address-settings></configuration>\n";
+
+      FileConfigurationParser parser = new FileConfigurationParser();
+      ByteArrayInputStream input = new ByteArrayInputStream(configStr.getBytes(StandardCharsets.UTF_8));
+
+      Configuration configuration = parser.parseMainConfig(input);
+      Assert.assertEquals("()", configuration.getLiteralMatchMarkers());
+   }
+
+   @Test
+   public void testViewPermissionMethodMatchPattern() throws Exception {
+      final String pattern = "^(get|list).+$";
+      String configStr = "<configuration><view-permission-method-match-pattern>" + pattern + "</view-permission-method-match-pattern>\n</configuration>\n";
+
+      FileConfigurationParser parser = new FileConfigurationParser();
+      ByteArrayInputStream input = new ByteArrayInputStream(configStr.getBytes(StandardCharsets.UTF_8));
+
+      Configuration configuration = parser.parseMainConfig(input);
+      Assert.assertEquals(pattern, configuration.getViewPermissionMethodMatchPattern());
+   }
+
+   @Test
+   public void testManagementRbacPrefix() throws Exception {
+      final String pattern = "j.m.x";
+      String configStr = "<configuration><management-rbac-prefix>" + pattern + "</management-rbac-prefix>\n</configuration>\n";
+
+      FileConfigurationParser parser = new FileConfigurationParser();
+      ByteArrayInputStream input = new ByteArrayInputStream(configStr.getBytes(StandardCharsets.UTF_8));
+
+      Configuration configuration = parser.parseMainConfig(input);
+      Assert.assertEquals(pattern, configuration.getManagementRbacPrefix());
+   }
+
+   @Test
+   public void testManagementRbac() throws Exception {
+      final boolean enabled = true;
+      String configStr = "<configuration><management-message-rbac>" + enabled + "</management-message-rbac>\n</configuration>\n";
+
+      FileConfigurationParser parser = new FileConfigurationParser();
+      ByteArrayInputStream input = new ByteArrayInputStream(configStr.getBytes(StandardCharsets.UTF_8));
+
+      Configuration configuration = parser.parseMainConfig(input);
+      Assert.assertEquals(enabled, configuration.isManagementMessageRbac());
+   }
+
    // you should not use K, M notations on address settings max-size-messages
    @Test
    public void testExpectedErrorOverMaxMessageNotation() throws Exception {
@@ -696,12 +752,21 @@ public class FileConfigurationParserTest extends ActiveMQTestBase {
       }
 
       Assert.assertTrue(exception);
-
-
-
    }
 
+   @Test
+   public void testSyncLargeMessage() throws Throwable {
+      StringPrintStream stringPrintStream = new StringPrintStream();
+      PrintStream stream = stringPrintStream.newStream();
 
+      stream.println("<configuration><core>");
+      stream.println("<large-message-sync>false</large-message-sync>");
+      stream.println("</core></configuration>");
+      FileConfigurationParser parser = new FileConfigurationParser();
+      ByteArrayInputStream inputStream = new ByteArrayInputStream(stringPrintStream.getBytes());
+      Configuration configuration = parser.parseMainConfig(inputStream);
+      Assert.assertFalse(configuration.isLargeMessageSync());
+   }
 
    private static String firstPart = "<core xmlns=\"urn:activemq:core\">" + "\n" +
       "<name>ActiveMQ.main.config</name>" + "\n" +
