@@ -1,20 +1,19 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with
+ * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * <p>
- * http://www.apache.org/licenses/LICENSE-2.0
- * <p>
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.activemq.artemis.core.server.impl.jdbc;
 
 import java.sql.Connection;
@@ -37,11 +36,10 @@ import org.apache.activemq.artemis.core.server.NodeManager.LockListener;
 import org.apache.activemq.artemis.jdbc.store.drivers.JDBCUtils;
 import org.apache.activemq.artemis.jdbc.store.sql.SQLProvider;
 import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
-import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
+import org.apache.activemq.artemis.tests.util.ServerTestBase;
 import org.apache.activemq.artemis.utils.Wait;
 import org.apache.activemq.artemis.utils.actors.ArtemisExecutor;
 import org.apache.activemq.artemis.utils.actors.OrderedExecutorFactory;
-import org.hamcrest.MatcherAssert;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Assume;
@@ -51,13 +49,8 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameter;
 
-import static org.hamcrest.Matchers.greaterThanOrEqualTo;
-import static org.hamcrest.Matchers.lessThan;
-import static org.hamcrest.core.Is.is;
-import static org.hamcrest.core.IsInstanceOf.instanceOf;
-
 @RunWith(Parameterized.class)
-public class JdbcLeaseLockTest extends ActiveMQTestBase {
+public class JdbcLeaseLockTest extends ServerTestBase {
 
    private JdbcSharedStateManager jdbcSharedStateManager;
    private DatabaseStorageConfiguration dbConf;
@@ -82,7 +75,7 @@ public class JdbcLeaseLockTest extends ActiveMQTestBase {
    private LeaseLock lock(long acquireMillis) {
       try {
          return JdbcSharedStateManager
-            .createLiveLock(
+            .createPrimaryLock(
                UUID.randomUUID().toString(),
                jdbcSharedStateManager.getJdbcConnectionProvider(),
                sqlProvider,
@@ -96,7 +89,7 @@ public class JdbcLeaseLockTest extends ActiveMQTestBase {
    private LeaseLock lock(long acquireMillis, long queryTimeoutMillis) {
       try {
          return JdbcSharedStateManager
-            .createLiveLock(
+            .createPrimaryLock(
                UUID.randomUUID().toString(),
                jdbcSharedStateManager.getJdbcConnectionProvider(),
                sqlProvider,
@@ -108,21 +101,6 @@ public class JdbcLeaseLockTest extends ActiveMQTestBase {
       }
    }
 
-   private LeaseLock lock(long acquireMillis, long queryTimeoutMillis, long allowedTimeDiff) {
-      try {
-         return JdbcSharedStateManager
-            .createLiveLock(
-               UUID.randomUUID().toString(),
-               jdbcSharedStateManager.getJdbcConnectionProvider(),
-               sqlProvider,
-               acquireMillis,
-               queryTimeoutMillis,
-               allowedTimeDiff);
-      } catch (Exception e) {
-         throw new IllegalStateException(e);
-      }
-   }
-
    @Before
    public void createLockTable() throws Exception {
       dbConf = createDefaultDatabaseStorageConfiguration();
@@ -367,7 +345,7 @@ public class JdbcLeaseLockTest extends ActiveMQTestBase {
       scheduledLeaseLock.lock().release();
       Assert.assertFalse(scheduledLeaseLock.lock().isHeldByCaller());
       TimeUnit.MILLISECONDS.sleep(3 * scheduledLeaseLock.renewPeriodMillis());
-      MatcherAssert.assertThat(lostLock.get(), is(greaterThanOrEqualTo(2L)));
+      Assert.assertTrue(lostLock.get() + " < 2", lostLock.get() >= 2L);
       scheduledLeaseLock.stop();
       executorService.shutdown();
       scheduledExecutorService.shutdown();
@@ -376,14 +354,14 @@ public class JdbcLeaseLockTest extends ActiveMQTestBase {
    @Test
    public void shouldJdbcAndSystemTimeToBeAligned() throws InterruptedException {
       final LeaseLock lock = lock(TimeUnit.SECONDS.toMillis(10), TimeUnit.SECONDS.toMillis(10));
-      Assume.assumeThat(lock, instanceOf(JdbcLeaseLock.class));
+      Assume.assumeTrue(lock + " is not an instance of JdbcLeaseLock", lock instanceof JdbcLeaseLock);
       final JdbcLeaseLock jdbcLock = JdbcLeaseLock.class.cast(lock);
       final long utcSystemTime = System.currentTimeMillis();
       TimeUnit.SECONDS.sleep(1);
       final long utcJdbcTime = jdbcLock.dbCurrentTimeMillis();
       final long millisDiffJdbcSystem = utcJdbcTime - utcSystemTime;
-      MatcherAssert.assertThat(millisDiffJdbcSystem, greaterThanOrEqualTo(0L));
-      MatcherAssert.assertThat(millisDiffJdbcSystem, lessThan(TimeUnit.SECONDS.toMillis(10)));
+      Assert.assertTrue(millisDiffJdbcSystem + " < 0", millisDiffJdbcSystem >= 0L);
+      Assert.assertTrue(millisDiffJdbcSystem + " >= 10_000", millisDiffJdbcSystem < 10_000);
    }
 
    @Test
@@ -425,36 +403,37 @@ public class JdbcLeaseLockTest extends ActiveMQTestBase {
    }
 
    @Test
-   public void validateTimeDiffsOnLeaseLock() {
-      AssertionLoggerHandler.startCapture();
-      runAfter(AssertionLoggerHandler::stopCapture);
+   public void validateTimeDiffsOnLeaseLock() throws Exception {
 
       AtomicInteger diff = new AtomicInteger(0);
 
-      JdbcLeaseLock hackLock = new JdbcLeaseLock("SomeID", jdbcSharedStateManager.getJdbcConnectionProvider(), sqlProvider.tryAcquireLiveLockSQL(),
-                               sqlProvider.tryReleaseLiveLockSQL(), sqlProvider.renewLiveLockSQL(),
-                               sqlProvider.isLiveLockedSQL(), sqlProvider.currentTimestampSQL(),
-                               sqlProvider.currentTimestampTimeZoneId(), -1, 1000,
-                               "LIVE", 1000) {
+      JdbcLeaseLock hackLock = new JdbcLeaseLock("SomeID", jdbcSharedStateManager.getJdbcConnectionProvider(), sqlProvider.tryAcquirePrimaryLockSQL(),
+                                                 sqlProvider.tryReleasePrimaryLockSQL(), sqlProvider.renewPrimaryLockSQL(),
+                                                 sqlProvider.isPrimaryLockedSQL(), sqlProvider.currentTimestampSQL(),
+                                                 sqlProvider.currentTimestampTimeZoneId(), -1, 1000,
+                                                 "PRIMARY", 1000) {
          @Override
          protected long fetchDatabaseTime(Connection connection) throws SQLException {
             return System.currentTimeMillis() + diff.get();
          }
       };
 
-      diff.set(10_000);
-      hackLock.dbCurrentTimeMillis();
-      Assert.assertTrue(AssertionLoggerHandler.findText("AMQ224118"));
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         diff.set(10_000);
+         hackLock.dbCurrentTimeMillis();
+         Assert.assertTrue(loggerHandler.findText("AMQ224118"));
+      }
 
-      diff.set(-10_000);
-      AssertionLoggerHandler.clear();
-      hackLock.dbCurrentTimeMillis();
-      Assert.assertTrue(AssertionLoggerHandler.findText("AMQ224118"));
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         diff.set(-10_000);
+         hackLock.dbCurrentTimeMillis();
+         Assert.assertTrue(loggerHandler.findText("AMQ224118"));
+      }
 
-      diff.set(0);
-      AssertionLoggerHandler.clear();
-      hackLock.dbCurrentTimeMillis();
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224118"));
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         diff.set(0);
+         hackLock.dbCurrentTimeMillis();
+         Assert.assertFalse(loggerHandler.findText("AMQ224118"));
+      }
    }
 }
-
