@@ -45,25 +45,21 @@ import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.tests.util.CFUtil;
 import org.apache.activemq.artemis.tests.util.RandomUtil;
 import org.apache.activemq.artemis.tests.util.Wait;
-import org.jboss.logging.Logger;
-import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 public class AutoCreateTest extends ActiveMQTestBase {
-   private static final Logger logger = Logger.getLogger(AutoCreateTest.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    public final SimpleString addressA = new SimpleString("addressA");
    public final SimpleString queueA = new SimpleString("queueA");
 
    private ActiveMQServer server;
 
-   @After
-   public void clearLogg() {
-      AssertionLoggerHandler.stopCapture();
-   }
-
    @Override
    @Before
    public void setUp() throws Exception {
@@ -71,8 +67,8 @@ public class AutoCreateTest extends ActiveMQTestBase {
       server = createServer(true, true);
       AddressSettings settings = new AddressSettings().setAutoCreateAddresses(true).setAutoDeleteAddresses(true).setAutoCreateQueues(true).setAutoDeleteQueues(true);
 
-      server.getConfiguration().getAddressesSettings().clear();
-      server.getConfiguration().getAddressesSettings().put("#", settings);
+      server.getConfiguration().getAddressSettings().clear();
+      server.getConfiguration().getAddressSettings().put("#", settings);
    }
 
    @Test
@@ -91,7 +87,7 @@ public class AutoCreateTest extends ActiveMQTestBase {
          for (int i = 0; i < 50; i++) {
             ConnectionFactory cf = CFUtil.createConnectionFactory("core", "tcp://localhost:61616");
             logger.debug("*******************************************************************************************************************************");
-            logger.debug("run " + i);
+            logger.debug("run {}", i);
             CyclicBarrier barrier = new CyclicBarrier(THREADS + 1);
             CountDownLatch done = new CountDownLatch(THREADS);
             Runnable consumerThread = () -> {
@@ -137,7 +133,6 @@ public class AutoCreateTest extends ActiveMQTestBase {
    @Test
    public void testSweep() throws Exception {
 
-      AssertionLoggerHandler.startCapture();
       server.getConfiguration().setAddressQueueScanPeriod(-1); // disabling scanner, we will perform it manually
       server.start();
       String QUEUE_NAME = "autoCreateAndRecreate";
@@ -166,22 +161,23 @@ public class AutoCreateTest extends ActiveMQTestBase {
       Assert.assertNotNull(info);
       Assert.assertTrue(info.isAutoCreated());
 
-      PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224112"));
-      PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-      Assert.assertTrue(AssertionLoggerHandler.findText("AMQ224112"));
-      Assert.assertTrue("Queue name should be mentioned on logs", AssertionLoggerHandler.findText(QUEUE_NAME));
-      PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-      Assert.assertTrue(AssertionLoggerHandler.findText("AMQ224113")); // we need another sweep to remove it
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
+         Assert.assertFalse(loggerHandler.findText("AMQ224112"));
+         PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
+         Assert.assertTrue(loggerHandler.findText("AMQ224112"));
+         Assert.assertTrue("Queue name should be mentioned on logs", loggerHandler.findText(QUEUE_NAME));
+         PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
+         Assert.assertTrue(loggerHandler.findText("AMQ224113")); // we need another sweep to remove it
+      }
    }
 
    @Test
    public void testSweepAddress() throws Exception {
-      AssertionLoggerHandler.startCapture();
       server.getConfiguration().setAddressQueueScanPeriod(-1); // disabling scanner, we will perform it manually
       AddressSettings settings = new AddressSettings().setAutoDeleteQueues(true).setAutoDeleteAddresses(true).setAutoDeleteAddressesDelay(10).setAutoDeleteQueuesDelay(10);
-      server.getConfiguration().getAddressesSettings().clear();
-      server.getConfiguration().getAddressesSettings().put("#", settings);
+      server.getConfiguration().getAddressSettings().clear();
+      server.getConfiguration().getAddressSettings().put("#", settings);
       server.start();
       String ADDRESS_NAME = getName();
 
@@ -201,24 +197,25 @@ public class AutoCreateTest extends ActiveMQTestBase {
          Wait.assertTrue(() -> infoRef.getBindingRemovedTimestamp() != -1);
       }
 
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224113"));
-      Thread.sleep(50);
-      Assert.assertFalse(info.isSwept());
-      PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224113"));
-      Assert.assertTrue(info.isSwept());
-      PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-      Assert.assertTrue(AssertionLoggerHandler.findText("AMQ224113"));
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         Assert.assertFalse(loggerHandler.findText("AMQ224113"));
+         Thread.sleep(50);
+         Assert.assertFalse(info.isSwept());
+         PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
+         Assert.assertFalse(loggerHandler.findText("AMQ224113"));
+         Assert.assertTrue(info.isSwept());
+         PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
+         Assert.assertTrue(loggerHandler.findText("AMQ224113"));
+      }
    }
 
 
    @Test
    public void testNegativeSweepAddress() throws Exception {
-      AssertionLoggerHandler.startCapture();
       server.getConfiguration().setAddressQueueScanPeriod(-1); // disabling scanner, we will perform it manually
       AddressSettings settings = new AddressSettings().setAutoDeleteQueues(true).setAutoDeleteAddresses(true).setAutoDeleteAddressesDelay(10).setAutoDeleteQueuesDelay(10);
-      server.getConfiguration().getAddressesSettings().clear();
-      server.getConfiguration().getAddressesSettings().put("#", settings);
+      server.getConfiguration().getAddressSettings().clear();
+      server.getConfiguration().getAddressSettings().put("#", settings);
       server.start();
       String ADDRESS_NAME = getName();
 
@@ -238,25 +235,26 @@ public class AutoCreateTest extends ActiveMQTestBase {
          Wait.assertTrue(() -> infoRef.getBindingRemovedTimestamp() != -1);
       }
 
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224113"));
-      Thread.sleep(50);
-      PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224113"));
-      Assert.assertTrue(info.isSwept());
-      try (Connection connection = cf.createConnection()) {
-         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-         Topic topic = session.createTopic(ADDRESS_NAME);
-         session.createConsumer(topic);
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         Assert.assertFalse(loggerHandler.findText("AMQ224113"));
+         Thread.sleep(50);
          PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-         Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224113"));
-         Assert.assertFalse(info.isSwept()); // it should be cleared because there is a consumer now
+         Assert.assertFalse(loggerHandler.findText("AMQ224113"));
+         Assert.assertTrue(info.isSwept());
+         try (Connection connection = cf.createConnection()) {
+            Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+            Topic topic = session.createTopic(ADDRESS_NAME);
+            session.createConsumer(topic);
+            PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
+            Assert.assertFalse(loggerHandler.findText("AMQ224113"));
+            Assert.assertFalse(info.isSwept()); // it should be cleared because there is a consumer now
+         }
       }
    }
 
    @Test
    public void testNegativeSweepBecauseOfConsumer() throws Exception {
 
-      AssertionLoggerHandler.startCapture();
       server.getConfiguration().setAddressQueueScanPeriod(-1); // disabling scanner, we will perform it manually
       server.start();
       String QUEUE_NAME = getName();
@@ -273,27 +271,26 @@ public class AutoCreateTest extends ActiveMQTestBase {
       Assert.assertNotNull(info);
       Assert.assertTrue(info.isAutoCreated());
 
-
-      try (Connection connection = cf.createConnection()) {
+      try (Connection connection = cf.createConnection();
+         AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
          Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
          Queue queue = session.createQueue(QUEUE_NAME);
          PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
          org.apache.activemq.artemis.core.server.Queue serverQueue = server.locateQueue(QUEUE_NAME);
          Assert.assertTrue(serverQueue.isSwept());
-         Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224112"));
+         Assert.assertFalse(loggerHandler.findText("AMQ224112"));
          MessageConsumer consumer = session.createConsumer(queue);
          PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
          Assert.assertFalse(serverQueue.isSwept());
          PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-         Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224113")); // we need another sweep to remove it
-         Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224112"));
+         Assert.assertFalse(loggerHandler.findText("AMQ224113")); // we need another sweep to remove it
+         Assert.assertFalse(loggerHandler.findText("AMQ224112"));
       }
    }
 
    @Test
    public void testNegativeSweepBecauseOfSend() throws Exception {
 
-      AssertionLoggerHandler.startCapture();
       server.getConfiguration().setAddressQueueScanPeriod(-1); // disabling scanner, we will perform it manually
       server.start();
       String QUEUE_NAME = getName();
@@ -311,21 +308,22 @@ public class AutoCreateTest extends ActiveMQTestBase {
       Assert.assertTrue(info.isAutoCreated());
 
 
-      try (Connection connection = cf.createConnection()) {
+      try (Connection connection = cf.createConnection();
+         AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
          Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
          Queue queue = session.createQueue(QUEUE_NAME);
          PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
          org.apache.activemq.artemis.core.server.Queue serverQueue = server.locateQueue(QUEUE_NAME);
          Assert.assertTrue(serverQueue.isSwept());
-         Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224112"));
+         Assert.assertFalse(loggerHandler.findText("AMQ224112"));
          MessageProducer producer = session.createProducer(queue);
          producer.send(session.createTextMessage("hello"));
          Wait.assertEquals(1, serverQueue::getMessageCount);
          PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
          Assert.assertFalse(serverQueue.isSwept());
          PostOfficeTestAccessor.reapAddresses((PostOfficeImpl) server.getPostOffice());
-         Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224113")); // we need another sweep to remove it
-         Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224112"));
+         Assert.assertFalse(loggerHandler.findText("AMQ224113")); // we need another sweep to remove it
+         Assert.assertFalse(loggerHandler.findText("AMQ224112"));
       }
    }
 
@@ -353,10 +351,10 @@ public class AutoCreateTest extends ActiveMQTestBase {
          server.getAddressSettingsRepository().addMatch(getName(), new AddressSettings().setAutoCreateAddresses(true).setAutoDeleteAddressesDelay(TimeUnit.DAYS.toMillis(1)).setAutoDeleteQueuesDelay(TimeUnit.DAYS.toMillis(1)));
       }
 
-      AssertionLoggerHandler.startCapture();
       server.getConfiguration().setAddressQueueScanPeriod(-1); // disabling scanner, we will perform it manually
       server.start();
-      String QUEUE_NAME = getName();
+      String QUEUE_NAME = "QUEUE_" + getName();
+      String TOPIC_NAME = "TOPIC_" + getName();
 
       ConnectionFactory cf = CFUtil.createConnectionFactory(protocol, "tcp://localhost:61616");
       try (Connection connection = cf.createConnection()) {
@@ -371,36 +369,51 @@ public class AutoCreateTest extends ActiveMQTestBase {
       Assert.assertTrue(info.isAutoCreated());
 
       server.stop();
-      server.start();
 
-      Assert.assertTrue(AssertionLoggerHandler.findText("AMQ224113"));
-      Assert.assertTrue(AssertionLoggerHandler.findText("AMQ224112"));
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         server.start();
 
-      AssertionLoggerHandler.clear();
+         Assert.assertTrue(loggerHandler.findText("AMQ224113"));
+         Assert.assertTrue(loggerHandler.findText("AMQ224112"));
+      }
 
       String randomString = "random " + RandomUtil.randomString();
 
       try (Connection connection = cf.createConnection()) {
          Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
          Queue queue = session.createQueue(QUEUE_NAME);
-         MessageProducer producer = session.createProducer(queue);
-         producer.send(session.createTextMessage(randomString));
+         Topic topic = session.createTopic(TOPIC_NAME);
+         MessageProducer producer = session.createProducer(null);
+         producer.send(queue, session.createTextMessage(randomString));
+         producer.send(topic, session.createTextMessage(randomString));
       }
 
       info = server.getPostOffice().getAddressInfo(SimpleString.toSimpleString(QUEUE_NAME));
       Assert.assertNotNull(info);
       Assert.assertTrue(info.isAutoCreated());
 
-      server.stop();
-      server.start();
+      info = server.getPostOffice().getAddressInfo(SimpleString.toSimpleString(TOPIC_NAME));
+      Assert.assertNotNull(info);
+      Assert.assertTrue(info.isAutoCreated());
 
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224113")); // this time around the queue had messages, it has to exist
-      Assert.assertFalse(AssertionLoggerHandler.findText("AMQ224112"));
+      server.stop();
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
+         server.start();
+
+         // this time around the address QUEUE_NAME had a queue with messages, it has to exist
+         Assert.assertFalse(loggerHandler.matchText("AMQ224113.*" + QUEUE_NAME));
+         Assert.assertFalse(loggerHandler.findText("AMQ224112"));
+         // the address TOPIC_NAME had no queues, it has to be removed
+         Assert.assertTrue(loggerHandler.matchText("AMQ224113.*" + TOPIC_NAME));
+      }
 
       info = server.getPostOffice().getAddressInfo(SimpleString.toSimpleString(QUEUE_NAME));
       Assert.assertNotNull(info);
       Assert.assertTrue(info.isAutoCreated());
 
+      info = server.getPostOffice().getAddressInfo(SimpleString.toSimpleString(TOPIC_NAME));
+      Assert.assertNull(info);
+
       { // just a namespace
          org.apache.activemq.artemis.core.server.Queue serverQueue = server.locateQueue(QUEUE_NAME);
          Wait.assertEquals(1, serverQueue::getMessageCount);
