@@ -188,11 +188,62 @@ public class NotificationTest extends ActiveMQTestBase {
       Assert.assertTrue(notifications[0].getTimestamp() >= start);
       Assert.assertTrue((long) notifications[0].getObjectProperty(ManagementHelper.HDR_NOTIFICATION_TIMESTAMP) >= start);
       Assert.assertEquals(notifications[0].getTimestamp(), (long) notifications[0].getObjectProperty(ManagementHelper.HDR_NOTIFICATION_TIMESTAMP));
+      Assert.assertNull(notifications[0].getSimpleStringProperty(ManagementHelper.HDR_FILTERSTRING));
 
       consumer.close();
       session.deleteQueue(queue);
    }
 
+   @Test
+   public void testConsumerCreatedWithEmptyFilterString() throws Exception {
+
+      SimpleString queue = RandomUtil.randomSimpleString();
+      SimpleString address = RandomUtil.randomSimpleString();
+      SimpleString filter = SimpleString.toSimpleString("");
+      boolean durable = RandomUtil.randomBoolean();
+
+      try (
+            ClientSessionFactory sf = createSessionFactory(locator);
+            ClientSession clientSession = sf.createSession("myUser", "myPassword", false, true, true, locator.isPreAcknowledge(), locator.getAckBatchSize());
+      ) {
+         clientSession.start();
+         session.createQueue(new QueueConfiguration(queue).setAddress(address).setDurable(durable));
+         NotificationTest.flush(notifConsumer);
+         try (ClientConsumer ignored = clientSession.createConsumer(queue, filter)) {
+            ClientMessage[] notifications = NotificationTest.consumeMessages(1, notifConsumer);
+            Assert.assertNull(notifications[0].getSimpleStringProperty(ManagementHelper.HDR_FILTERSTRING));
+         }
+      } finally {
+         session.deleteQueue(queue);
+      }
+   }
+
+   @Test
+   public void testSuppressSessionNotifications() throws Exception {
+      server.getConfiguration().setSuppressSessionNotifications(false);
+      ClientSessionFactory sf = createSessionFactory(locator);
+
+      NotificationTest.flush(notifConsumer);
+      ClientSession mySession = sf.createSession("myUser", "myPassword", false, true, true, locator.isPreAcknowledge(), locator.getAckBatchSize());
+
+      mySession.start();
+      ClientMessage[] notifications = NotificationTest.consumeMessages(1, notifConsumer);
+      Assert.assertEquals(SESSION_CREATED.toString(), notifications[0].getObjectProperty(ManagementHelper.HDR_NOTIFICATION_TYPE).toString());
+      mySession.close();
+      notifications = NotificationTest.consumeMessages(1, notifConsumer);
+      Assert.assertEquals(SESSION_CLOSED.toString(), notifications[0].getObjectProperty(ManagementHelper.HDR_NOTIFICATION_TYPE).toString());
+
+      NotificationTest.flush(notifConsumer);
+      server.getConfiguration().setSuppressSessionNotifications(true);
+      mySession = sf.createSession("myUser", "myPassword", false, true, true, locator.isPreAcknowledge(), locator.getAckBatchSize());
+
+      mySession.start();
+      NotificationTest.consumeMessages(0, notifConsumer);
+      mySession.close();
+      NotificationTest.consumeMessages(0, notifConsumer);
+
+   }
+
    @Test
    public void testCONSUMER_CLOSED() throws Exception {
       ClientSessionFactory sf = createSessionFactory(locator);
