@@ -423,7 +423,7 @@ public class MQTTTest extends MQTTTestSupport {
    @Ignore
    @Test(timeout = 600 * 1000)
    public void testSendMoreThanUniqueId() throws Exception {
-      int messages = (Short.MAX_VALUE * 2) + 1;
+      int messages = MQTTUtil.TWO_BYTE_INT_MAX;
 
       final MQTTClientProvider publisher = getMQTTClientProvider();
       initializeConnection(publisher);
@@ -447,6 +447,63 @@ public class MQTTTest extends MQTTTestSupport {
       publisher.disconnect();
    }
 
+   @Test(timeout = 600 * 1000)
+   public void testNoMessageIdReuseBeforeAcknowledgment() throws Exception {
+      final int messages = MQTTUtil.TWO_BYTE_INT_MAX;
+
+      final MQTTClientProvider publisher = getMQTTClientProvider();
+      initializeConnection(publisher);
+
+      final MQTT mqtt = createMQTTConnection();
+      mqtt.setClientId("foo");
+      final short[] messageId = new short[1];
+      mqtt.setTracer(new Tracer() {
+         @Override
+         public void onReceive(MQTTFrame frame) {
+            if (frame.messageType() == PUBLISH.TYPE) {
+               try {
+                  PUBLISH publish = new PUBLISH();
+                  publish.decode(frame);
+                  messageId[0] = publish.messageId();
+               } catch (ProtocolException e) {
+                  fail("Error decoding publish " + e.getMessage());
+               }
+            }
+         }
+      });
+      final BlockingConnection connection = mqtt.blockingConnection();
+      connection.connect();
+      connection.subscribe(new Topic[]{new Topic("foo", QoS.EXACTLY_ONCE)});
+
+      publisher.publish("foo", "First Message".getBytes(), EXACTLY_ONCE);
+      final Message firstMessage = connection.receive(5000, TimeUnit.MILLISECONDS);
+      final short firstMessageId = messageId[0];
+
+      publisher.publish("foo", "Second Message".getBytes(), EXACTLY_ONCE);
+      final Message secondMessage = connection.receive(5000, TimeUnit.MILLISECONDS);
+      final short secondMessageId = messageId[0];
+
+      int count = 0;
+      for (int i = 0; i < messages; i++) {
+         String payload = "Test Message: " + i;
+         publisher.publish("foo", payload.getBytes(), EXACTLY_ONCE);
+         Message message = connection.receive(5000, TimeUnit.MILLISECONDS);
+         assertNotNull("Should get a message + [" + i + "]", message);
+         assertEquals(payload, new String(message.getPayload()));
+         assertFalse("Message ID must not be reused until previous message acknowledgment", firstMessageId == messageId[0] || secondMessageId == messageId[0]);
+         message.ack();
+         count++;
+      }
+
+      firstMessage.ack();
+      secondMessage.ack();
+
+      assertEquals(messages, count);
+      connection.unsubscribe(new String[]{"foo"});
+      connection.disconnect();
+      publisher.disconnect();
+   }
+
    @Test(timeout = 60 * 1000)
    public void testSendAndReceiveLargeMessages() throws Exception {
       byte[] payload = new byte[1024 * 32];
@@ -1903,10 +1960,10 @@ public class MQTTTest extends MQTTTestSupport {
       Exception peerDisconnectedException = null;
       try {
          String clientId = "test.client";
-         String coreAddress = MQTTUtil.convertMqttTopicFilterToCore("foo/bar", server.getConfiguration().getWildcardConfiguration());
+         String coreAddress = MQTTUtil.getCoreAddressFromMqttTopic("foo/bar", server.getConfiguration().getWildcardConfiguration());
          Topic[] mqttSubscription = new Topic[]{new Topic("foo/bar", QoS.AT_LEAST_ONCE)};
 
-         getServer().createQueue(new QueueConfiguration(new SimpleString(clientId + "." + coreAddress)).setAddress(coreAddress).setRoutingType(RoutingType.MULTICAST).setDurable(false).setTemporary(true).setMaxConsumers(0));
+         getServer().createQueue(new QueueConfiguration(MQTTUtil.getCoreQueueFromMqttTopic("foo/bar", clientId, server.getConfiguration().getWildcardConfiguration())).setAddress(coreAddress).setRoutingType(RoutingType.MULTICAST).setDurable(false).setTemporary(true).setMaxConsumers(0));
 
          MQTT mqtt = createMQTTConnection();
          mqtt.setClientId(clientId);
@@ -2151,11 +2208,11 @@ public class MQTTTest extends MQTTTestSupport {
    @Test(timeout = 60 * 1000)
    public void testAutoDeleteRetainedQueue() throws Exception {
       final String TOPIC = "/abc/123";
-      final String RETAINED_QUEUE = MQTTUtil.convertMqttTopicFilterToCore(MQTTUtil.MQTT_RETAIN_ADDRESS_PREFIX, TOPIC, server.getConfiguration().getWildcardConfiguration());
+      final String RETAINED_QUEUE = MQTTUtil.getCoreRetainAddressFromMqttTopic(TOPIC, server.getConfiguration().getWildcardConfiguration());
       final MQTTClientProvider publisher = getMQTTClientProvider();
       final MQTTClientProvider subscriber = getMQTTClientProvider();
 
-      server.getAddressSettingsRepository().addMatch(MQTTUtil.convertMqttTopicFilterToCore("#", server.getConfiguration().getWildcardConfiguration()), new AddressSettings().setExpiryDelay(500L).setAutoDeleteQueues(true).setAutoDeleteAddresses(true));
+      server.getAddressSettingsRepository().addMatch(MQTTUtil.getCoreAddressFromMqttTopic("#", server.getConfiguration().getWildcardConfiguration()), new AddressSettings().setExpiryDelay(500L).setAutoDeleteQueues(true).setAutoDeleteAddresses(true));
 
       initializeConnection(publisher);
       initializeConnection(subscriber);
