@@ -23,16 +23,14 @@ import java.util.concurrent.Future;
 import java.util.concurrent.TimeUnit;
 
 import org.apache.activemq.artemis.core.config.Configuration;
-import org.apache.activemq.artemis.core.config.ha.SharedStoreMasterPolicyConfiguration;
+import org.apache.activemq.artemis.core.config.ha.SharedStorePrimaryPolicyConfiguration;
 import org.apache.activemq.artemis.core.server.ActiveMQServer;
 import org.apache.activemq.artemis.core.server.JournalType;
 import org.apache.activemq.artemis.nativo.jlibaio.LibaioContext;
 import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
 import org.apache.activemq.artemis.utils.ActiveMQThreadFactory;
-import org.junit.AfterClass;
 import org.junit.Assert;
-import org.junit.BeforeClass;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -40,21 +38,11 @@ public class FileLockTimeoutTest extends ActiveMQTestBase {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
-   @BeforeClass
-   public static void prepareLogger() {
-      AssertionLoggerHandler.startCapture();
-   }
-
-   @AfterClass
-   public static void clearLogger() {
-      AssertionLoggerHandler.stopCapture();
-   }
-
    protected void doTest(final boolean useAIO) throws Exception {
       if (useAIO) {
          Assert.assertTrue(String.format("libAIO is not loaded on %s %s %s", System.getProperty("os.name"), System.getProperty("os.arch"), System.getProperty("os.version")), LibaioContext.isLoaded());
       }
-      Configuration config = super.createDefaultInVMConfig().setHAPolicyConfiguration(new SharedStoreMasterPolicyConfiguration()).clearAcceptorConfigurations();
+      Configuration config = super.createDefaultInVMConfig().setHAPolicyConfiguration(new SharedStorePrimaryPolicyConfiguration()).clearAcceptorConfigurations();
 
       ActiveMQServer server1 = createServer(true, config);
       if (useAIO) {
@@ -85,17 +73,19 @@ public class FileLockTimeoutTest extends ActiveMQTestBase {
          }
       };
 
-      Future<?> f = service.submit(r);
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler(true)) {
+         Future<?> f = service.submit(r);
 
-      try {
-         f.get(15, TimeUnit.SECONDS);
-      } catch (Exception e) {
-         logger.warn("aborting test because server is taking too long to start");
+         try {
+            f.get(15, TimeUnit.SECONDS);
+         } catch (Exception e) {
+            logger.warn("aborting test because server is taking too long to start");
+         }
+
+         service.shutdown();
+
+         assertTrue("Expected to find AMQ224000", loggerHandler.findText("AMQ224000"));
+         assertTrue("Expected to find \"Timed out waiting for lock\"", loggerHandler.findTrace("Timed out waiting for lock"));
       }
-
-      service.shutdown();
-
-      assertTrue("Expected to find AMQ224000", AssertionLoggerHandler.findText("AMQ224000"));
-      assertTrue("Expected to find \"timed out waiting for lock\"", AssertionLoggerHandler.findText("timed out waiting for lock"));
    }
 }
