@@ -46,18 +46,38 @@ import org.apache.activemq.artemis.tests.util.CFUtil;
 import org.apache.activemq.artemis.utils.RandomUtil;
 import org.apache.activemq.artemis.utils.SpawnedVMSupport;
 import org.apache.activemq.artemis.utils.Wait;
-import org.jboss.logging.Logger;
+import org.apache.activemq.artemis.utils.cli.helper.HelperCreate;
 import org.junit.Before;
+import org.junit.BeforeClass;
 import org.junit.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 public class M_and_M_FactoryTest extends SoakTestBase {
 
-   private static final Logger logger = Logger.getLogger(M_and_M_FactoryTest.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    public static final String SERVER_NAME_0 = "mmfactory";
    private static final String JMX_SERVER_HOSTNAME = "localhost";
    private static final int JMX_SERVER_PORT = 11099;
 
+   @BeforeClass
+   public static void createServers() throws Exception {
+      {
+         File serverLocation = getFileServerLocation(SERVER_NAME_0);
+         deleteDirectory(serverLocation);
+
+         HelperCreate cliCreateServer = new HelperCreate();
+         cliCreateServer.setUser("admin").setPassword("admin").setAllowAnonymous(true).setNoWeb(false).setArtemisInstance(serverLocation);
+         cliCreateServer.setConfiguration("./src/main/resources/servers/mmfactory");
+         cliCreateServer.setArgs("--java-options", "-Djava.rmi.server.hostname=localhost -Dcom.sun.management.jmxremote=true -Dcom.sun.management.jmxremote.port=11099 -Dcom.sun.management.jmxremote.rmi.port=11098 -Dcom.sun.management.jmxremote.ssl=false -Dcom.sun.management.jmxremote.authenticate=false");
+
+         cliCreateServer.createServer();
+      }
+   }
+
+
    String theprotocol;
    int BATCH_SIZE;
    // how many times the server will be restarted
@@ -121,7 +141,7 @@ public class M_and_M_FactoryTest extends SoakTestBase {
       this.killClientEveryX = killClientEveryX;
       for (int i = 0; i < restarts; i++) {
          logger.debug("*******************************************************************************************************************************");
-         logger.debug("Starting " + clientRuns);
+         logger.debug("Starting {}", clientRuns);
          logger.debug("*******************************************************************************************************************************");
          testMMSorting(clientRuns * i, clientRuns * (i + 1));
 
@@ -143,7 +163,6 @@ public class M_and_M_FactoryTest extends SoakTestBase {
       MBeanServerConnection mBeanServerConnection = jmxConnector.getMBeanServerConnection();
       String brokerName = "0.0.0.0";  // configured e.g. in broker.xml <broker-name> element
       ObjectNameBuilder objectNameBuilder = ObjectNameBuilder.create(ActiveMQDefaultConfiguration.getDefaultJmxDomain(), brokerName, true);
-      //ActiveMQServerControl activeMQServerControl = MBeanServerInvocationHandler.newProxyInstance(mBeanServerConnection, objectNameBuilder.getActiveMQServerObjectName(), ActiveMQServerControl.class, false);
 
       ObjectName queueObjectName = objectNameBuilder.getQueueObjectName(SimpleString.toSimpleString("MMFactory"), SimpleString.toSimpleString("MMConsumer"), RoutingType.MULTICAST);
       QueueControl queueControl = MBeanServerInvocationHandler.newProxyInstance(mBeanServerConnection, queueObjectName, QueueControl.class, false);
@@ -207,7 +226,7 @@ public class M_and_M_FactoryTest extends SoakTestBase {
                      consumers[1].destroyForcibly();
                      consumers[1] = startConsumerProcess(theprotocol, timeForConsumers[1], "MMFactory::MMConsumer", 100, 1);
                      logger.debug("...Reconnected");
-                     logger.debug("retry=" + retryNumber + ",sent=" + i + ", acked on this batch = " + (queueControl.getMessagesAcknowledged() - (retryNumber.get() * BATCH_SIZE * 2)) + ", total acked = " + queueControl.getMessagesAcknowledged());
+                     logger.debug("retry={},sent={}, acked on this batch = {}, total acked = {}", retryNumber, i, (queueControl.getMessagesAcknowledged() - (retryNumber.get() * BATCH_SIZE * 2)), queueControl.getMessagesAcknowledged());
                   }
                   TextMessage message = session.createTextMessage("This is blue " + largeString);
                   message.setStringProperty("color", "blue");
@@ -220,7 +239,7 @@ public class M_and_M_FactoryTest extends SoakTestBase {
                   mmsFactory.send(message);
 
                   if (i % 10 == 0) {
-                     logger.debug("Sending " + i + " run = " + run);
+                     logger.debug("Sending {} run = {}", i, run);
                   }
 
                   if (i == 0) {
@@ -241,15 +260,13 @@ public class M_and_M_FactoryTest extends SoakTestBase {
                   if ((queueControl.getMessagesAcknowledged() + queueControl.getMessagesKilled() + queueControl.getMessagesExpired()) - (retryNumber.get() * BATCH_SIZE * 2) > (BATCH_SIZE * 2 - 500)) {
                      return true;
                   } else {
-                     logger.debug("Received " + queueControl.getMessagesAcknowledged());
+                     logger.debug("Received {}", queueControl.getMessagesAcknowledged());
                      return false;
                   }
                }, 45_000, 1_000);
 
                expectedTotalSize += BATCH_SIZE * 2;
-               Wait.assertEquals(expectedTotalSize, queueControl::getMessagesAdded);
 
-               Wait.assertEquals(expectedTotalSize, () -> queueControl.getMessagesAcknowledged() + queueControl.getMessagesKilled());
                retryNumber.incrementAndGet();
 
                for (Process c : consumers) {
@@ -258,7 +275,7 @@ public class M_and_M_FactoryTest extends SoakTestBase {
                for (int i = 0; i < consumers.length; i++) {
                   File file = new File(getConsumerLog(i));
                   if (!file.delete()) {
-                     logger.debug("not possible to remove " + file);
+                     logger.debug("not possible to remove {}", file);
                   }
                }
                for (int r = 0; r < consumers.length; r++) {
@@ -278,13 +295,13 @@ public class M_and_M_FactoryTest extends SoakTestBase {
             for (int i = 0; i < consumers.length; i++) {
                File file = new File(getConsumerLog(i));
                if (!file.delete()) {
-                  logger.warn("not possible to remove " + file);
+                  logger.warn("not possible to remove {}", file);
                }
             }
 
             File file = new File(getConsumerLog(1000)); //the DLQ processing ID used
             if (!file.delete()) {
-               logger.warn("not possible to remove " + file);
+               logger.warn("not possible to remove {}", file);
             }
          }
       }
@@ -295,10 +312,10 @@ public class M_and_M_FactoryTest extends SoakTestBase {
       Wait.waitFor(() -> {
 
          if (lastTime.get() == queueControl.getMessagesAcknowledged()) {
-            logger.debug("Waiting some change on " + queueControl.getMessagesAcknowledged() + " with messages Added = " + queueControl.getMessagesAdded() + " and killed = " + queueControl.getMessagesKilled());
+            logger.debug("Waiting some change on {} with messages Added = {} and killed = {}", queueControl.getMessagesAcknowledged(), queueControl.getMessagesAdded(), queueControl.getMessagesKilled());
             return false;
          } else {
-            logger.debug("Condition met! with " + queueControl.getMessagesAcknowledged() + " with messages Added = " + queueControl.getMessagesAdded() + " and killed = " + queueControl.getMessagesKilled());
+            logger.debug("Condition met! with {} with messages Added = {} and killed = {}", queueControl.getMessagesAcknowledged(), queueControl.getMessagesAdded(), queueControl.getMessagesKilled());
             lastTime.set((int)queueControl.getMessagesAcknowledged());
             return true;
          }
@@ -339,7 +356,7 @@ public class M_and_M_FactoryTest extends SoakTestBase {
             String color = message.getStringProperty("color");
             int messageSequence = message.getIntProperty("i");
             if (queuename.equals("DLQ")) {
-               logger.debug("Processing DLQ on color=" + color + ", sequence=" + messageSequence);
+               logger.debug("Processing DLQ on color={}, sequence={}", color, messageSequence);
             } else if (slowTime > 0) {
                Thread.sleep(slowTime);
             }
