@@ -17,7 +17,6 @@
 package org.apache.activemq.artemis.tests.unit.ra;
 
 import javax.xml.parsers.DocumentBuilder;
-import javax.xml.parsers.DocumentBuilderFactory;
 import java.io.ByteArrayInputStream;
 import java.io.InputStream;
 import java.lang.reflect.Method;
@@ -26,6 +25,7 @@ import java.util.Map;
 
 import org.apache.activemq.artemis.ra.ActiveMQResourceAdapter;
 import org.apache.activemq.artemis.tests.util.ActiveMQTestBase;
+import org.apache.activemq.artemis.utils.XmlProvider;
 import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -342,6 +342,12 @@ public class ActiveMQResourceAdapterConfigTest extends ActiveMQTestBase {
       "         <config-property-value>false</config-property-value>" +
       "      </config-property>\n" +
       "      <config-property>\n" +
+      "         <description>The level of compression to use. Must be -1 or between 0-9</description>" +
+      "         <config-property-name>CompressionLevel</config-property-name>" +
+      "         <config-property-type>int</config-property-type>" +
+      "         <config-property-value>-1</config-property-value>" +
+      "      </config-property>\n" +
+      "      <config-property>\n" +
       "         <description>The timeout in milliseconds for failover call (or -1 for infinite)</description>\n" +
       "         <config-property-name>CallFailoverTimeout</config-property-name>\n" +
       "         <config-property-type>long</config-property-type>\n" +
@@ -408,12 +414,24 @@ public class ActiveMQResourceAdapterConfigTest extends ActiveMQTestBase {
       "         <config-property-value></config-property-value>" +
       "      </config-property>" +
       "      <config-property>" +
+      "         <description>List of package/class names against which matching objects are permitted to be deserialized</description>" +
+      "         <config-property-name>DeserializationAllowList</config-property-name>" +
+      "         <config-property-type>java.lang.String</config-property-type>" +
+      "         <config-property-value></config-property-value>" +
+      "      </config-property>" +
+      "      <config-property>" +
       "         <description>List of package/class names against which matching objects are forbidden to be deserialized</description>" +
       "         <config-property-name>DeserializationBlackList</config-property-name>" +
       "         <config-property-type>java.lang.String</config-property-type>" +
       "         <config-property-value></config-property-value>" +
       "      </config-property>" +
       "      <config-property>" +
+      "         <description>List of package/class names against which matching objects are forbidden to be deserialized</description>" +
+      "         <config-property-name>DeserializationDenyList</config-property-name>" +
+      "         <config-property-type>java.lang.String</config-property-type>" +
+      "         <config-property-value></config-property-value>" +
+      "      </config-property>" +
+      "      <config-property>" +
       "         <description>***add***</description>" +
       "         <config-property-name>IgnoreJTA</config-property-name>" +
       "         <config-property-type>boolean</config-property-type>" +
@@ -443,8 +461,7 @@ public class ActiveMQResourceAdapterConfigTest extends ActiveMQTestBase {
             methodList.put(method.getName(), method);
          }
       }
-      DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
-      DocumentBuilder db = dbf.newDocumentBuilder();
+      DocumentBuilder db = XmlProvider.newDocumentBuilder();
       InputStream io = new ByteArrayInputStream(rootConfig.getBytes());
       Document dom = db.parse(new InputSource(io));
 
